/**
 * Copyright (c) 2013-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.base.junit.shell;

import java.io.PrintStream;
import java.util.Map;

import org.ow2.petals.cli.api.command.Command;
import org.ow2.petals.cli.api.command.ConnectionCommand;
import org.ow2.petals.cli.api.command.DisconnectionCommand;
import org.ow2.petals.cli.api.connection.ConnectionParameters;
import org.ow2.petals.cli.api.exception.NoInteractiveShellException;
import org.ow2.petals.cli.api.pref.Preferences;
import org.ow2.petals.cli.api.shell.Shell;
import org.ow2.petals.cli.api.shell.ShellExtension;
import org.ow2.petals.cli.api.shell.exception.ConnectionCommandAlreadyRegisteredException;
import org.ow2.petals.cli.api.shell.exception.DisconnectionCommandAlreadyRegisteredException;
import org.ow2.petals.cli.api.shell.exception.DuplicatedCommandException;
import org.ow2.petals.cli.api.shell.exception.ShellException;

/**
 * <p>
 * A dummy implementation of {@link Shell} where all methods does nothing except:
 * <ul>
 * <li>method returning <b>boolean</b> returns <b>false</b>,</li>
 * <li>method returning {@link Object} returns <b>null</b>,</li>
 * <li>{@link #setConnectionParameters(ConnectionParameters)} and {@link #getConnectionParameters()}.</li>
 * </ul>
 * </p>
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class DummyShell implements Shell {

    private ConnectionParameters connectionParameters = null;

    @Override
    public void registersCommand(final Command command) throws DuplicatedCommandException, IllegalArgumentException {
        // NOP
    }

    @Override
    public Map<String, Command> getCommands() {
        return null;
    }

    @Override
    public void exit(final int status) {
        // NOP
    }

    @Override
    public void setExitStatus(final int exitStatus) {
        // NOP
    }

    @Override
    public PrintStream getPrintStream() {
        return null;
    }

    @Override
    public String interpolate(final String str) {
        return null;
    }

    @Override
    public PrintStream getErrorStream() {
        return null;
    }

    @Override
    public String askQuestion(final String question, final boolean isReplyPassword) throws NoInteractiveShellException,
            ShellException {
        return null;
    }

    @Override
    public boolean confirms(final String message) throws ShellException {
        return false;
    }

    @Override
    public boolean isInteractive() {
        return false;
    }

    @Override
    public void setPrompt(final String prompt) {
        // NOP
    }

    @Override
    public boolean isDebugModeEnable() {
        return false;
    }

    @Override
    public void setConnectionParameters(final ConnectionParameters connectionParameters) {
        this.connectionParameters = connectionParameters;
    }

    @Override
    public ConnectionParameters getConnectionParameters() {
        return this.connectionParameters;
    }

    @Override
    public boolean isAsynchronousCommandInProgress() {
        return false;
    }

    @Override
    public void addAsynchronousCommand() {
        // NOP
    }

    @Override
    public void removeAsynchronousCommand() {
        // NOP
    }

    @Override
    public void registersConnectionCommand(final ConnectionCommand connectionCommand)
            throws ConnectionCommandAlreadyRegisteredException, DuplicatedCommandException, IllegalArgumentException {
        // NOP
    }

    @Override
    public void registersDisconnectionCommand(final DisconnectionCommand disconnectionCommand)
            throws DisconnectionCommandAlreadyRegisteredException, DuplicatedCommandException, IllegalArgumentException {
        // NOP
    }

    @Override
    public ConnectionCommand getConnectionCommand() {
        return null;
    }

    @Override
    public DisconnectionCommand getDisconnectionCommand() {
        return null;
    }

    @Override
    public void setDefaultPrompt() {
        // NOP
    }

    @Override
    public ShellExtension[] getExtensions() {
        return null;
    }

    @Override
    public Preferences getPreferences() {
        return null;
    }

    @Override
    public void onConnectionEstablished() {
        // NOP
    }

    @Override
    public void onDisconnection() {
        // NOP
    }

    @Override
    public boolean isConnectionEstablished() {
        return false;
    }
}
